'''Module for flake8 funtionality.'''


def runFlake8(package_name):
    print('Running Flake8 for %s...' % package_name)
